@@ -14,6 +14,7 @@
 
 #include "snapd-error.h"
 #include "snapd-app.h"
+#include "snapd-category.h"
 #include "snapd-media.h"
 #include "snapd-screenshot.h"
 #include "snapd-task.h"
@@ -330,6 +331,26 @@ parse_error_response (JsonObject *root, JsonNode **error_value, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_UNSUCCESSFUL,
                              message);
+    else if (g_strcmp0 (kind, "app-not-found") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_APP_NOT_FOUND,
+                             message);
+    else if (g_strcmp0 (kind, "snap-architecture-not-available") == 0)
+         g_set_error_literal (error,
+                              SNAPD_ERROR,
+                              SNAPD_ERROR_ARCHITECTURE_NOT_AVAILABLE,
+                              message);
+    else if (g_strcmp0 (kind, "snap-change-conflict") == 0)
+         g_set_error_literal (error,
+                              SNAPD_ERROR,
+                              SNAPD_ERROR_CHANGE_CONFLICT,
+                              message);
+    else if (g_strcmp0 (kind, "interfaces-unchanged") == 0)
+         g_set_error_literal (error,
+                              SNAPD_ERROR,
+                              SNAPD_ERROR_INTERFACES_UNCHANGED,
+                              message);
     else {
         switch (status_code) {
         case SOUP_STATUS_BAD_REQUEST:
@@ -584,6 +605,7 @@ _snapd_json_parse_system_information (JsonNode *node, GError **error)
     }
     JsonObject *object = json_node_get_object (node);
 
+    const gchar *architecture = _snapd_json_get_string (object, "architecture", "");
     const gchar *confinement_string = _snapd_json_get_string (object, "confinement", "");
     SnapdSystemConfinement confinement = SNAPD_SYSTEM_CONFINEMENT_UNKNOWN;
     if (strcmp (confinement_string, "strict") == 0)
@@ -631,6 +653,7 @@ _snapd_json_parse_system_information (JsonNode *node, GError **error)
     g_autoptr(GDateTime) refresh_next = _snapd_json_get_date_time (refresh, "next");
 
     return g_object_new (SNAPD_TYPE_SYSTEM_INFORMATION,
+                         "architecture", architecture,
                          "binaries-directory", locations != NULL ? _snapd_json_get_string (locations, "snap-bin-dir", NULL) : NULL,
                          "build-id", _snapd_json_get_string (object, "build-id", NULL),
                          "confinement", confinement,
@@ -708,6 +731,24 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
         g_ptr_array_add (apps_array, app);
     }
 
+    g_autoptr(JsonArray) categories = _snapd_json_get_array (object, "categories");
+    g_autoptr(GPtrArray) categories_array = g_ptr_array_new_with_free_func (g_object_unref);
+    for (guint i = 0; i < json_array_get_length (categories); i++) {
+        JsonNode *node = json_array_get_element (categories, i);
+
+        if (json_node_get_value_type (node) != JSON_TYPE_OBJECT) {
+            g_set_error (error, SNAPD_ERROR, SNAPD_ERROR_READ_FAILED, "Unexpected categories type");
+            return NULL;
+        }
+
+        JsonObject *c = json_node_get_object (node);
+        g_autoptr(SnapdCategory) category = g_object_new (SNAPD_TYPE_CATEGORY,
+                                                          "featured", _snapd_json_get_bool (c, "featured", FALSE),
+                                                          "name", _snapd_json_get_string (c, "name", NULL),
+                                                          NULL);
+        g_ptr_array_add (categories_array, g_steal_pointer (&category));
+    }
+
     JsonObject *channels = _snapd_json_get_object (object, "channels");
     g_autoptr(GPtrArray) channels_array = g_ptr_array_new_with_free_func (g_object_unref);
     if (channels != NULL) {
@@ -753,6 +794,7 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
     g_ptr_array_add (common_ids_array, NULL);
 
     g_autoptr(GDateTime) install_date = _snapd_json_get_date_time (object, "install-date");
+    g_autoptr(GDateTime) hold = _snapd_json_get_date_time (object, "hold");
 
     JsonObject *prices = _snapd_json_get_object (object, "prices");
     g_autoptr(GPtrArray) prices_array = g_ptr_array_new_with_free_func (g_object_unref);
@@ -841,6 +883,7 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
                          "apps", apps_array,
                          "base", _snapd_json_get_string (object, "base", NULL),
                          "broken", _snapd_json_get_string (object, "broken", NULL),
+                         "categories", categories_array,
                          "channel", _snapd_json_get_string (object, "channel", NULL),
                          "channels", channels_array,
                          "common-ids", (GStrv) common_ids_array->pdata,
@@ -849,6 +892,7 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
                          "description", _snapd_json_get_string (object, "description", NULL),
                          "devmode", _snapd_json_get_bool (object, "devmode", FALSE),
                          "download-size", _snapd_json_get_int (object, "download-size", 0),
+                         "hold", hold,
                          "icon", _snapd_json_get_string (object, "icon", NULL),
                          "id", _snapd_json_get_string (object, "id", NULL),
                          "install-date", install_date,
