@@ -35,6 +35,7 @@ struct _SnapdSnap
     GPtrArray *apps;
     gchar *base;
     gchar *broken;
+    GPtrArray *categories;
     gchar *channel;
     GPtrArray *channels;
     GStrv common_ids;
@@ -43,6 +44,7 @@ struct _SnapdSnap
     gchar *description;
     gboolean devmode;
     gint64 download_size;
+    GDateTime *hold;
     gchar *icon;
     gchar *id;
     GDateTime *install_date;
@@ -75,6 +77,7 @@ struct _SnapdSnap
 enum
 {
     PROP_APPS = 1,
+    PROP_CATEGORIES,
     PROP_CHANNEL,
     PROP_CONFINEMENT,
     PROP_CONTACT,
@@ -113,6 +116,7 @@ enum
     PROP_MOUNTED_FROM,
     PROP_MEDIA,
     PROP_WEBSITE,
+    PROP_HOLD,
     PROP_LAST
 };
 
@@ -169,6 +173,23 @@ snapd_snap_get_broken (SnapdSnap *self)
     return self->broken;
 }
 
+/**
+ * snapd_snap_get_categories:
+ * @snap: a #SnapdSnap.
+ *
+ * Gets the categories this snap belongs to.
+ *
+ * Returns: (transfer none) (element-type SnapdCategory): an array of #SnapdCategory.
+ *
+ * Since: 1.64
+ */
+GPtrArray *
+snapd_snap_get_categories (SnapdSnap *self)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (self), NULL);
+    return self->categories;
+}
+
 /**
  * snapd_snap_get_channel:
  * @snap: a #SnapdSnap.
@@ -385,6 +406,24 @@ snapd_snap_get_download_size (SnapdSnap *self)
     return self->download_size;
 }
 
+/**
+ * snapd_snap_get_hold:
+ * @snap: a #SnapdSnap.
+ *
+ * Get the date this snap will re-enable automatic refreshing or %NULL if no hold is present.
+ *
+ * Returns: (transfer none) (allow-none): a #GDateTime or %NULL.
+ *
+ * Since: 1.64
+ */
+GDateTime *
+snapd_snap_get_hold (SnapdSnap *self)
+{
+    g_return_val_if_fail (SNAPD_IS_SNAP (self), NULL);
+    return self->hold;
+}
+
+
 /**
  * snapd_snap_get_icon:
  * @snap: a #SnapdSnap.
@@ -870,6 +909,11 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
         g_free (self->broken);
         self->broken = g_strdup (g_value_get_string (value));
         break;
+    case PROP_CATEGORIES:
+        g_clear_pointer (&self->categories, g_ptr_array_unref);
+        if (g_value_get_boxed (value) != NULL)
+            self->categories = g_ptr_array_ref (g_value_get_boxed (value));
+        break;
     case PROP_CHANNEL:
         g_free (self->channel);
         self->channel = g_strdup (g_value_get_string (value));
@@ -896,6 +940,11 @@ snapd_snap_set_property (GObject *object, guint prop_id, const GValue *value, GP
     case PROP_DOWNLOAD_SIZE:
         self->download_size = g_value_get_int64 (value);
         break;
+    case PROP_HOLD:
+        g_clear_pointer (&self->hold, g_date_time_unref);
+        if (g_value_get_boxed (value) != NULL)
+            self->hold = g_date_time_ref (g_value_get_boxed (value));
+        break;
     case PROP_ICON:
         g_free (self->icon);
         self->icon = g_strdup (g_value_get_string (value));
@@ -1027,6 +1076,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_BROKEN:
         g_value_set_string (value, self->broken);
         break;
+    case PROP_CATEGORIES:
+        g_value_set_boxed (value, self->categories);
+        break;
     case PROP_CHANNEL:
         g_value_set_string (value, self->channel);
         break;
@@ -1048,6 +1100,9 @@ snapd_snap_get_property (GObject *object, guint prop_id, GValue *value, GParamSp
     case PROP_DOWNLOAD_SIZE:
         g_value_set_int64 (value, self->download_size);
         break;
+    case PROP_HOLD:
+        g_value_set_boxed (value, self->hold);
+        break;
     case PROP_ICON:
         g_value_set_string (value, self->icon);
         break;
@@ -1147,11 +1202,13 @@ snapd_snap_finalize (GObject *object)
     g_clear_pointer (&self->apps, g_ptr_array_unref);
     g_clear_pointer (&self->base, g_free);
     g_clear_pointer (&self->broken, g_free);
+    g_clear_pointer (&self->categories, g_ptr_array_unref);
     g_clear_pointer (&self->channel, g_free);
     g_clear_pointer (&self->channels, g_ptr_array_unref);
     g_clear_pointer (&self->common_ids, g_strfreev);
     g_clear_pointer (&self->contact, g_free);
     g_clear_pointer (&self->description, g_free);
+    g_clear_pointer (&self->hold, g_date_time_unref);
     g_clear_pointer (&self->icon, g_free);
     g_clear_pointer (&self->id, g_free);
     g_clear_pointer (&self->install_date, g_date_time_unref);
@@ -1192,6 +1249,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                          "Apps this snap contains",
                                                          G_TYPE_PTR_ARRAY,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_CATEGORIES,
+                                     g_param_spec_boxed ("categories",
+                                                         "categories",
+                                                         "Categories this snap belongs to",
+                                                         G_TYPE_PTR_ARRAY,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_BASE,
                                      g_param_spec_string ("base",
@@ -1269,6 +1333,13 @@ snapd_snap_class_init (SnapdSnapClass *klass)
                                                          "Download size in bytes",
                                                          G_MININT64, G_MAXINT64, 0,
                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_HOLD,
+                                     g_param_spec_boxed ("hold",
+                                                         "hold",
+                                                         "Date this snap will re-enable automatic refreshing",
+                                                         G_TYPE_DATE_TIME,
+                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
     g_object_class_install_property (gobject_class,
                                      PROP_ICON,
                                      g_param_spec_string ("icon",
